@@ -7,7 +7,10 @@
 */
 
 #include "kaddressbookpart.h"
+#include <kcoreaddons_version.h>
+#if KCOREADDONS_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include "kaddressbookmigrateapplication.h"
+#endif
 #include "mainwidget.h"
 
 #include "kaddressbook_debug.h"
@@ -25,11 +28,13 @@ KAddressBookPart::KAddressBookPart(QWidget *parentWidget, QObject *parent, const
     : KParts::Part(parent)
 {
     setComponentName(QStringLiteral("kaddressbook"), i18n("KAddressBook"));
+#if KCOREADDONS_VERSION < QT_VERSION_CHECK(6, 0, 0)
     KAddressBookMigrateApplication migrate;
     migrate.migrate();
+#endif
 
     // create a canvas to insert our widget
-    QWidget *canvas = new QWidget(parentWidget);
+    auto canvas = new QWidget(parentWidget);
     canvas->setFocusPolicy(Qt::ClickFocus);
     setWidget(canvas);
     auto topLayout = new QVBoxLayout(canvas);
@@ -49,7 +54,7 @@ void KAddressBookPart::updateQuickSearchText()
 
 void KAddressBookPart::initAction()
 {
-    QAction *action = new QAction(QIcon::fromTheme(QStringLiteral("configure")), i18n("&Configure KAddressBook..."), this);
+    auto action = new QAction(QIcon::fromTheme(QStringLiteral("configure")), i18n("&Configure KAddressBook..."), this);
     actionCollection()->addAction(QStringLiteral("kaddressbook_configure"), action);
     connect(action, &QAction::triggered, mMainWidget, &MainWidget::configure);
 }
